summaryrefslogtreecommitdiffstats
path: root/sound/usb/line6/driver.h
diff options
context:
space:
mode:
authorChris Rorvick <chris@rorvick.com>2015-01-20 09:20:49 +0100
committerTakashi Iwai <tiwai@suse.de>2015-01-20 09:52:30 +0100
commitc6fffce92e1a8cda8c1b552f5a24295839f3f93a (patch)
treebd550e912d3cea8916757d8e65e946a33515a0e1 /sound/usb/line6/driver.h
parentALSA: line6: Remove superfluous NULL checks (diff)
downloadlinux-c6fffce92e1a8cda8c1b552f5a24295839f3f93a.tar.xz
linux-c6fffce92e1a8cda8c1b552f5a24295839f3f93a.zip
ALSA: line6: Refer to manufacturer as "Line 6"
The correct spelling includes the space. Fix this in strings and comments that refer to the manufacturer. Signed-off-by: Chris Rorvick <chris@rorvick.com> Signed-off-by: Takashi Iwai <tiwai@suse.de>
Diffstat (limited to 'sound/usb/line6/driver.h')
-rw-r--r--sound/usb/line6/driver.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/sound/usb/line6/driver.h b/sound/usb/line6/driver.h
index d539c11d333d..ff52169bb5a1 100644
--- a/sound/usb/line6/driver.h
+++ b/sound/usb/line6/driver.h
@@ -1,5 +1,5 @@
/*
* Line6 Linux USB driver - 0.9.1beta
*
* Copyright (C) 2004-2010 Markus Grabner (grabner@icg.tugraz.at)
*
@@ -25,7 +25,7 @@
#define LINE6_MESSAGE_MAXLEN 256
/*
- Line6 MIDI control commands
+ Line 6 MIDI control commands
*/
#define LINE6_PARAM_CHANGE 0xb0
#define LINE6_PROGRAM_CHANGE 0xc0
@@ -61,7 +61,7 @@ static const int SYSEX_DATA_OFS = sizeof(line6_midi_id) + 3;
static const int SYSEX_EXTRA_SIZE = sizeof(line6_midi_id) + 4;
/**
- Common properties of Line6 devices.
+ Common properties of Line 6 devices.
*/
struct line6_properties {
/**
@@ -91,7 +91,7 @@ struct line6_properties {
};
/**
- Common data shared by all Line6 devices.
+ Common data shared by all Line 6 devices.
Corresponds to a pair of USB endpoints.
*/
struct usb_line6 {
@@ -121,18 +121,18 @@ struct usb_line6 {
struct device *ifcdev;
/**
- Line6 sound card data structure.
+ Line 6 sound card data structure.
Each device has at least MIDI or PCM.
*/
struct snd_card *card;
/**
- Line6 PCM device data structure.
+ Line 6 PCM device data structure.
*/
struct snd_line6_pcm *line6pcm;
/**
- Line6 MIDI device data structure.
+ Line 6 MIDI device data structure.
*/
struct snd_line6_midi *line6midi;
@@ -1,5 +1,5 @@
/*
- * Line6 Linux USB driver - 0.9.1beta
+ * Line 6 Linux USB driver - 0.9.1beta
*
* Copyright (C) 2004-2010 Markus Grabner (grabner@icg.tugraz.at)